@@ -1,19 +1,19 @@
 import os
 import shutil
 
-from evident.diversity_handler import (_BaseDiversityHandler,
-                                       AlphaDiversityHandler,
-                                       BetaDiversityHandler)
+from evident.data_handler import (_BaseDataHandler,
+                                  UnivariateDataHandler,
+                                  MultivariateDataHandler)
 
 
 def create_bokeh_app(
-    diversity_handler: _BaseDiversityHandler,
+    data_handler: _BaseDataHandler,
     output: os.PathLike,
 ) -> None:
     """Creates interactive power analysis using Bokeh.
 
-    :param diversity_handler: Handler with diversity data
-    :type diversity_handler: evident.diversity_handler._BaseDiversityHandler
+    :param data_handler: Handler with data
+    :type data_handler: evident.data_handler._BaseDataHandler
 
     :param output: Location to create Bokeh app
     :type output: os.PathLike
@@ -26,16 +26,16 @@ def create_bokeh_app(
     data_dir = os.path.join(output, "data")
     os.mkdir(data_dir)
 
-    md = diversity_handler.metadata.copy()
+    md = data_handler.metadata.copy()
     md_loc = os.path.join(data_dir, "metadata.tsv")
     md.to_csv(md_loc, sep="\t", index=True)
 
-    data = diversity_handler.data
-    if isinstance(diversity_handler, AlphaDiversityHandler):
-        data_loc = os.path.join(data_dir, "diversity.alpha.tsv")
+    data = data_handler.data
+    if isinstance(data_handler, UnivariateDataHandler):
+        data_loc = os.path.join(data_dir, "data.univariate.tsv")
         data.to_csv(data_loc, sep="\t", index=True)
-    elif isinstance(diversity_handler, BetaDiversityHandler):
-        data_loc = os.path.join(data_dir, "diversity.beta.lsmat")
+    elif isinstance(data_handler, MultivariateDataHandler):
+        data_loc = os.path.join(data_dir, "data.multivariate.lsmat")
         data.write(data_loc)
     else:
         raise ValueError("No valid data found!")
