@@ -4,7 +4,7 @@ import click
 import pandas as pd
 from skbio import DistanceMatrix
 
-from evident import AlphaDiversityHandler, BetaDiversityHandler
+from evident import UnivariateDataHandler, MultivariateDataHandler
 from evident.interactive import create_bokeh_app
 
 
@@ -20,11 +20,11 @@ def interactive(output, diversity_type):
     df = df.dropna(axis=0)
 
     if diversity_type == "alpha":
-        dh = AlphaDiversityHandler(df["faith_pd"], df)
+        dh = UnivariateDataHandler(df["faith_pd"], df)
     elif diversity_type == "beta":
         dm_loc = os.path.join(curr_path, "data/distance_matrix.lsmat.gz")
         dm = DistanceMatrix.read(dm_loc)
-        dh = BetaDiversityHandler(dm, df)
+        dh = MultivariateDataHandler(dm, df)
     else:
         raise ValueError("No valid data!")
 
